ApiException class

General API exception for HTTP errors.

Inheritance
Implementers

Constructors

ApiException(String message, {int? statusCode, StackTrace? stackTrace})
Creates an ApiException with an optional statusCode and stackTrace.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message describing the exception.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace associated with the exception, if any.
finalinherited
statusCode int?
The HTTP status code, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited