FilterCondition<T> class

Typed version of FilterCondition that provides compile-time type safety.

Properties

field FieldSelector<T>
The field selector with type information
final
hashCode int
The hash code for this object.
no setteroverride
operator FilterOperator
The comparison operator
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value FilterValue<T>
The typed value to compare against
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override