IdConflictException class

Exception thrown when ID conflicts cannot be resolved.

Implemented types

Constructors

IdConflictException(String message, {required String temporaryId, required String proposedServerId, required String modelType})
Creates a new IdConflictException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
final
modelType String
The model type involved in the conflict.
final
proposedServerId String
The proposed server ID that conflicts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporaryId String
The temporary client ID that caused the conflict.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited