ModelInfoRegistryProvider class

Global provider for model metadata including cascade delete relationships

This class follows the same pattern as SynquillRepositoryProvider to provide runtime access to generated model metadata.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCascadeDeleteRelations(String modelTypeName) List<CascadeDeleteRelation>
Gets cascade delete relations for a model type
getDebugInfo() Map<String, dynamic>
Gets debug information about the current registry state
getForeignKeyRelations(String targetModelType) List<ForeignKeyRelation>
Gets all foreign key relations that reference a target model type
getModelsWithCascadeDelete() List<String>
Gets all registered model types that have cascade delete relations
registerCascadeDeleteRelations(String modelTypeName, List<CascadeDeleteRelation> relations) → void
Registers cascade delete relations for a model type
registerForeignKeyRelations(String targetModelType, List<ForeignKeyRelation> relations) → void
Registers foreign key relations for a target model type
reset() → void
Clears all registered model information