RealtimeApiAdapter<TModel extends SynquillDataModel<TModel>> class abstract

Optional capability for adapters that can stream remote realtime changes.

Constructors

RealtimeApiAdapter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribeEvents({String? id, QueryParams? queryParams, Map<String, String>? headers, Map<String, dynamic>? extra}) Stream<RealtimeEvent<TModel>>
Subscribes to remote realtime events for this model type.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited