RealtimeEventType enum

The semantic kind of a realtime change received from a remote transport.

Inheritance
Available extensions

Values

created → const RealtimeEventType

A new remote item was created.

updated → const RealtimeEventType

An existing remote item was updated.

deleted → const RealtimeEventType

A remote item was deleted.

upserted → const RealtimeEventType

A remote item should be inserted or replaced locally.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RealtimeEventType>
A constant List of the values in this enum, in order of their declaration.