SingleValue<T> class
Single value for most filter operations
- Inheritance
-
- Object
- FilterValue<
T> - SingleValue
Constructors
- SingleValue(T value)
-
Creates a SingleValue with the given value
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The single value to be used in filter comparison
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override