SortCondition<T> class

Typed version of SortCondition that provides compile-time safety for field names.

Constructors

SortCondition({required FieldSelector<T> field, required SortDirection direction})
Creates a new typed sort condition.
const
SortCondition.ascending(FieldSelector<T> field)
Creates an ascending sort condition.
const
SortCondition.descending(FieldSelector<T> field)
Creates a descending sort condition.
const

Properties

direction SortDirection
The sort direction
final
field FieldSelector<T>
The field selector with type information
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override