ValidationException class

Thrown when validation fails on the server side.

Inheritance

Constructors

ValidationException(String message, [Map<String, List<String>>? fieldErrors, StackTrace? stackTrace])
Creates a ValidationException with optional fieldErrors and stackTrace.

Properties

fieldErrors Map<String, List<String>>?
Field-specific validation errors, if provided by the server.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message describing the exception.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace associated with the exception, if any.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited