replace<T extends Table, D> method
Replaces the row from the table with the updated values. The row in
the table with the same primary key will be replaced.
See also:
- UpdateStatement.replace, which is what would be used outside of a Batch.
Implementation
void replace<T extends Table, D>(TableInfo<T, D> table, Insertable<D> row) {
_addUpdate(table, UpdateKind.update);
final stmt = UpdateStatement(_user, table)..replace(row, dontExecute: true);
_addContext(stmt.constructQuery());
}