desc method
Sort this column in descending order (10 -> 1 | Z -> A | Dec 31 -> Jan 1).
The optional nulls parameter can be used to control whether NULL
values in the column should come for or after non-null values.
Implementation
ComposableOrdering desc({NullsOrder? nulls}) => $composableOrdering({
OrderingBuilder(OrderingMode.desc, column, nulls: nulls),
});