runSelect method
Runs a select statement with the given variables and returns the raw results.
Implementation
@override
Future<List<Map<String, Object?>>> runSelect(
String statement,
List<Object?> args,
) => executor.runSelect(statement, args);
Runs a select statement with the given variables and returns the raw results.
@override
Future<List<Map<String, Object?>>> runSelect(
String statement,
List<Object?> args,
) => executor.runSelect(statement, args);