DatabaseConnectionUser constructor

DatabaseConnectionUser(
  1. QueryExecutor executor, {
  2. StreamQueryStore? streamQueries,
})

Constructs a database connection user, which is responsible to store query streams, wrap the underlying executor and perform type mapping.

Implementation

DatabaseConnectionUser(
  QueryExecutor executor, {
  StreamQueryStore? streamQueries,
}) : connection = executor is DatabaseConnection
         ? executor
         : DatabaseConnection(executor, streamQueries: streamQueries);