nulls property
How to order NULLs.
When nulls is null, then it's ignored.
Note that this feature are only available in sqlite3 version 3.30.0 and
newer.
Implementation
final NullsOrder? nulls;
How to order NULLs.
When nulls is null, then it's ignored.
Note that this feature are only available in sqlite3 version 3.30.0 and
newer.
final NullsOrder? nulls;