TableUpdateQuery.onTable constructor

TableUpdateQuery.onTable(
  1. ResultSetImplementation table, {
  2. UpdateKind? limitUpdateKind,
})

A query that listens for all updates on a specific table.

The optional limitUpdateKind parameter can be used to limit the updates to a certain kind.

Implementation

factory TableUpdateQuery.onTable(
  ResultSetImplementation table, {
  UpdateKind? limitUpdateKind,
}) {
  if (table is ViewInfo) {
    return TableUpdateQuery.allOf([
      for (final table in table.readTables)
        TableUpdateQuery.onTableName(table),
    ]);
  }

  return TableUpdateQuery.onTableName(
    table.entityName,
    limitUpdateKind: limitUpdateKind,
  );
}