Value<T>.absent constructor

const Value<T>.absent()

Create an absent value that will not be written into the database, the default value or null will be used instead.

Implementation

const Value.absent() : _value = null, present = false;