validateIntegrity method
VerificationContext
validateIntegrity(
- Insertable<
D> instance, { - bool isInserting = false,
inherited
Validates that the given entity can be inserted into this table, meaning that it respects all constraints (nullability, text length, etc.).
Implementation
VerificationContext validateIntegrity(
Insertable<D> instance, {
bool isInserting = false,
}) {
// default behavior when users chose to not verify the integrity (build time
// option)
return const VerificationContext.notEnabled();
}