DatabaseProvider class
Global database provider for the synced data storage system
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → GeneratedDatabase
-
Gets the global database instance
no setter
- instanceOrNull → GeneratedDatabase?
-
Gets the global database instance without throwing
no setter
Static Methods
-
reset(
) → void - Clears the database instance (primarily for testing)
-
setInstance(
GeneratedDatabase database) → void - Sets the global database instance