IdGenerationStrategy enum
Strategy for ID generation in models.
Values
- client → const IdGenerationStrategy
-
Client-generated IDs (default, backward compatible). Uses CUID generation on the client side.
- server → const IdGenerationStrategy
-
Server-generated IDs (replaces temporary client IDs after sync). Temporary client IDs are used until server assigns permanent IDs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IdGenerationStrategy> - A constant List of the values in this enum, in order of their declaration.