QueueStats class
Statistics for a request queue.
Constructors
- QueueStats({required int activeAndPendingTasks, required int pendingTasks})
-
Creates a new QueueStats instance
const
Properties
- activeAndPendingTasks → int
-
The total number of tasks that are currently active or pending
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pendingTasks → int
-
The number of tasks that are pending execution
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited