watchFromLocal method
Watches a single item from the local database by its ID.
This is a placeholder that should be overridden by concrete repository. QueryParams Additional query parameters for filtering (applied to local queries).
Implementation
@protected
Stream<T?> watchFromLocal(String id, {QueryParams? queryParams}) {
log.warning('watchFromLocal() not implemented for $T');
return Stream<T?>.empty();
}