SyncStatusConverter class
Drift type converter for SyncStatus enum
Converts between database String representation and SyncStatus enum
- Inheritance
-
- Object
- TypeConverter<
SyncStatus?, String?> - SyncStatusConverter
Constructors
- SyncStatusConverter()
-
Creates a new SyncStatusConverter.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromSql(
String? fromDb) → SyncStatus? -
Maps a column from the database back to Dart.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toSql(
SyncStatus? value) → String? -
Map a value from an object in Dart into something that will be understood
by the database.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited