writeStartPart method
Subclasses must override this and write the part of the statement that comes before the where and limit expression..
Implementation
@override
void writeStartPart(GenerationContext ctx) {
// TODO support the OR (ROLLBACK / ABORT / REPLACE / FAIL / IGNORE...) thing
ctx.buffer.write('UPDATE ${table.tableWithAlias} SET ');
writeInsertable(ctx, _updatedFields);
}